CompilationJob

Struct CompilationJob 

pub struct CompilationJob<T, F> { /* private fields */ }
The interface of LUNIR’s compilation pipeline. CompilationJob allows you to pass in parameters to the LUNIR compilation pipeline and invoke it, even across threads.

Implementations

Source

impl<'a, T> CompilationJob<T, NoSerializer>

pub fn serializer<S: Fn(IlChunk) -> Vec<u8>>( self, serializer: S, ) -> CompilationJob<T, WithSerializer<S>>

Adds a target format serializer function to this CompilationJob to allow it to produce a final bytecode.

Source

impl<'a, F> CompilationJob<NoTree, F>

pub fn tree(self, tree: &'a Node) -> CompilationJob<WithTree<'a>, F>

Adds a source abstract syntax tree to this CompilationJob.

Source

impl<'a, S: Fn(IlChunk) -> Vec<u8>> CompilationJob<WithTree<'a>, WithSerializer<S>>

pub fn run(self) -> Vec<u8>

Invokes LUNIR’s compilation pipeline with the parameters passed through the CompilationJob. This will consume the job.