pub struct CompilationJob<T, F> { /* private fields */ }Expand description
The interface of LUNIR’s compilation pipeline. CompilationJob allows you to pass in parameters to the LUNIR compilation pipeline and invoke it, even across threads.
Implementations
Sourceimpl<'a, T> CompilationJob<T, NoSerializer>
impl<'a, T> CompilationJob<T, NoSerializer>
Sourcepub fn serializer<S: Fn(IlChunk) -> Vec<u8>>(
self,
serializer: S,
) -> CompilationJob<T, WithSerializer<S>>
pub fn serializer<S: Fn(IlChunk) -> Vec<u8>>( self, serializer: S, ) -> CompilationJob<T, WithSerializer<S>>
Adds a target format serializer function to this CompilationJob to allow it to produce a final bytecode.
Sourceimpl<'a, F> CompilationJob<NoTree, F>
impl<'a, F> CompilationJob<NoTree, F>
Sourcepub fn tree(self, tree: &'a Node) -> CompilationJob<WithTree<'a>, F>
pub fn tree(self, tree: &'a Node) -> CompilationJob<WithTree<'a>, F>
Adds a source abstract syntax tree to this CompilationJob.